summaryrefslogtreecommitdiff
path: root/usr.bin/netstat/route.c
diff options
context:
space:
mode:
authorAngelos D. Keromytis <angelos@cvs.openbsd.org>1999-02-24 22:57:36 +0000
committerAngelos D. Keromytis <angelos@cvs.openbsd.org>1999-02-24 22:57:36 +0000
commit05c33cc0e9b69b11c15233c8563522f9f9578bff (patch)
treecc4c2b1b543deef8e95cce0e5c7d7fa38d1426df /usr.bin/netstat/route.c
parentcdbc65579e74936995182700e6fa578b351b90ba (diff)
Grok protocol/address family PF_KEY.
Diffstat (limited to 'usr.bin/netstat/route.c')
-rw-r--r--usr.bin/netstat/route.c15
1 files changed, 8 insertions, 7 deletions
diff --git a/usr.bin/netstat/route.c b/usr.bin/netstat/route.c
index ced59780a73..12fc9619b1a 100644
--- a/usr.bin/netstat/route.c
+++ b/usr.bin/netstat/route.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: route.c,v 1.25 1998/06/23 22:40:40 millert Exp $ */
+/* $OpenBSD: route.c,v 1.26 1999/02/24 22:57:35 angelos Exp $ */
/* $NetBSD: route.c,v 1.15 1996/05/07 02:55:06 thorpej Exp $ */
/*
@@ -38,7 +38,7 @@
#if 0
static char sccsid[] = "from: @(#)route.c 8.3 (Berkeley) 3/9/94";
#else
-static char *rcsid = "$OpenBSD: route.c,v 1.25 1998/06/23 22:40:40 millert Exp $";
+static char *rcsid = "$OpenBSD: route.c,v 1.26 1999/02/24 22:57:35 angelos Exp $";
#endif
#endif /* not lint */
@@ -75,7 +75,8 @@ static char *rcsid = "$OpenBSD: route.c,v 1.25 1998/06/23 22:40:40 millert Exp $
#define INET
#endif
-#include <net/encap.h>
+#include <sys/socket.h>
+#include <netinet/ip_ipsp.h>
#include "netstat.h"
#define kget(p, d) (kread((u_long)(p), (char *)&(d), sizeof (d)))
@@ -159,7 +160,7 @@ routepr(rtree)
} else if (af == AF_UNSPEC || af == i) {
pr_family(i);
do_rtent = 1;
- if (i != AF_ENCAP)
+ if (i != PF_KEY)
pr_rthdr();
else
pr_encaphdr();
@@ -194,7 +195,7 @@ pr_family(af)
case AF_CCITT:
afname = "X.25";
break;
- case AF_ENCAP:
+ case PF_KEY:
afname = "Encap";
break;
case AF_APPLETALK:
@@ -230,7 +231,7 @@ pr_rthdr()
}
/*
* Print header for AF_ENCAP entries.
*/
void
pr_encaphdr()
@@ -532,7 +533,7 @@ p_rtentry(rt)
bcopy(kgetsa(rt_key(rt)), sa, sizeof(struct sockaddr));
- if (sa->sa_family == AF_ENCAP) {
+ if (sa->sa_family == PF_KEY) {
encap_print(rt);
return;
}
@@ -230,7 +231,7 @@ pr_rthdr()
}
/*
- * Print header for AF_ENCAP entries.
+ * Print header for PF_KEY entries.
*/
void